@@ -17,6 +17,6 @@ class ControllerWithParentClass extends AbstractController
      */
     public function indexAction()
     {
-        return array();
+        return [];
     }
 }
